# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_sso_config_patch_request import ApiV1SsoConfigPatchRequest  # noqa: E501

class TestApiV1SsoConfigPatchRequest(unittest.TestCase):
    """ApiV1SsoConfigPatchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SsoConfigPatchRequest:
        """Test ApiV1SsoConfigPatchRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SsoConfigPatchRequest`
        """
        model = ApiV1SsoConfigPatchRequest()  # noqa: E501
        if include_optional:
            return ApiV1SsoConfigPatchRequest(
                auth_provider = 'okta-saml',
                is_active = True,
                entry_point = '',
                issuer = '',
                cert = '',
                organization_id = ''
            )
        else:
            return ApiV1SsoConfigPatchRequest(
                organization_id = '',
        )
        """

    def testApiV1SsoConfigPatchRequest(self):
        """Test ApiV1SsoConfigPatchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
