# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner(BaseModel):
    """
    ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner
    """
    op: StrictStr = Field(...)
    secret_id: Optional[StrictStr] = Field(default=None, alias="secretId")
    __properties = ["op", "secretId"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner:
        """Create an instance of ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if secret_id (nullable) is None
        # and __fields_set__ contains the field
        if self.secret_id is None and "secret_id" in self.__fields_set__:
            _dict['secretId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner:
        """Create an instance of ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner.parse_obj(obj)

        _obj = ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner.parse_obj({
            "op": obj.get("op"),
            "secret_id": obj.get("secretId")
        })
        return _obj


