# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_pki_ca_post_request import ApiV1PkiCaPostRequest  # noqa: E501

class TestApiV1PkiCaPostRequest(unittest.TestCase):
    """ApiV1PkiCaPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1PkiCaPostRequest:
        """Test ApiV1PkiCaPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1PkiCaPostRequest`
        """
        model = ApiV1PkiCaPostRequest()  # noqa: E501
        if include_optional:
            return ApiV1PkiCaPostRequest(
                project_slug = '',
                type = 'root',
                friendly_name = '',
                common_name = '',
                organization = '',
                ou = '',
                country = '',
                province = '',
                locality = '',
                not_before = '',
                not_after = '',
                max_path_length = -1,
                key_algorithm = 'RSA_2048'
            )
        else:
            return ApiV1PkiCaPostRequest(
                project_slug = '',
                type = 'root',
                common_name = '',
                organization = '',
                ou = '',
                country = '',
                province = '',
                locality = '',
        )
        """

    def testApiV1PkiCaPostRequest(self):
        """Test ApiV1PkiCaPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
