# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_approval_requests_id_get200_response_approval import ApiV1SecretApprovalRequestsIdGet200ResponseApproval  # noqa: E501

class TestApiV1SecretApprovalRequestsIdGet200ResponseApproval(unittest.TestCase):
    """ApiV1SecretApprovalRequestsIdGet200ResponseApproval unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretApprovalRequestsIdGet200ResponseApproval:
        """Test ApiV1SecretApprovalRequestsIdGet200ResponseApproval
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretApprovalRequestsIdGet200ResponseApproval`
        """
        model = ApiV1SecretApprovalRequestsIdGet200ResponseApproval()  # noqa: E501
        if include_optional:
            return ApiV1SecretApprovalRequestsIdGet200ResponseApproval(
                id = '',
                policy_id = '',
                has_merged = True,
                status = 'open',
                conflicts = None,
                slug = '',
                folder_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                is_replicated = True,
                committer_user_id = '',
                status_changed_by_user_id = '',
                bypass_reason = '',
                policy = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_policy._api_v1_secret_approval_requests__id__get_200_response_approval_policy(
                    id = '', 
                    name = '', 
                    approvals = 1.337, 
                    approvers = [
                        infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                            user_id = '', 
                            email = '', 
                            first_name = '', 
                            last_name = '', 
                            username = '', )
                        ], 
                    secret_path = '', 
                    enforcement_level = '', ),
                environment = '',
                status_changed_by_user = infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                    user_id = '', 
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    username = '', ),
                committer_user = infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                    user_id = '', 
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    username = '', ),
                reviewers = [
                    infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_reviewers_inner._api_v1_secret_approval_requests__id__get_200_response_approval_reviewers_inner(
                        user_id = '', 
                        email = '', 
                        first_name = '', 
                        last_name = '', 
                        username = '', 
                        status = '', )
                    ],
                secret_path = '',
                commits = [
                    infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner(
                        id = '', 
                        secret_key = '', 
                        secret_value = '', 
                        secret_comment = '', 
                        secret_reminder_note = '', 
                        secret_reminder_repeat_days = 1.337, 
                        skip_multiline_encoding = True, 
                        metadata = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        op = '', 
                        tags = [
                            infisicalapi_client.models._api_v1_secret_snapshot__secret_snapshot_id__get_200_response_secret_snapshot_secret_versions_inner_tags_inner._api_v1_secret_snapshot__secretSnapshotId__get_200_response_secretSnapshot_secretVersions_inner_tags_inner(
                                id = '', 
                                slug = '', 
                                color = '', )
                            ], 
                        secret = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret(
                            id = '', 
                            version = 1.337, 
                            secret_key = '', 
                            secret_value = '', 
                            secret_comment = '', ), 
                        secret_version = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret_version._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secretVersion(
                            id = '', 
                            version = 1.337, 
                            secret_key = '', 
                            secret_value = '', 
                            secret_comment = '', ), )
                    ]
            )
        else:
            return ApiV1SecretApprovalRequestsIdGet200ResponseApproval(
                id = '',
                policy_id = '',
                slug = '',
                folder_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                committer_user_id = '',
                policy = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_policy._api_v1_secret_approval_requests__id__get_200_response_approval_policy(
                    id = '', 
                    name = '', 
                    approvals = 1.337, 
                    approvers = [
                        infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                            user_id = '', 
                            email = '', 
                            first_name = '', 
                            last_name = '', 
                            username = '', )
                        ], 
                    secret_path = '', 
                    enforcement_level = '', ),
                environment = '',
                committer_user = infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                    user_id = '', 
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    username = '', ),
                reviewers = [
                    infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_reviewers_inner._api_v1_secret_approval_requests__id__get_200_response_approval_reviewers_inner(
                        user_id = '', 
                        email = '', 
                        first_name = '', 
                        last_name = '', 
                        username = '', 
                        status = '', )
                    ],
                secret_path = '',
                commits = [
                    infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner(
                        id = '', 
                        secret_key = '', 
                        secret_value = '', 
                        secret_comment = '', 
                        secret_reminder_note = '', 
                        secret_reminder_repeat_days = 1.337, 
                        skip_multiline_encoding = True, 
                        metadata = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        op = '', 
                        tags = [
                            infisicalapi_client.models._api_v1_secret_snapshot__secret_snapshot_id__get_200_response_secret_snapshot_secret_versions_inner_tags_inner._api_v1_secret_snapshot__secretSnapshotId__get_200_response_secretSnapshot_secretVersions_inner_tags_inner(
                                id = '', 
                                slug = '', 
                                color = '', )
                            ], 
                        secret = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret(
                            id = '', 
                            version = 1.337, 
                            secret_key = '', 
                            secret_value = '', 
                            secret_comment = '', ), 
                        secret_version = infisicalapi_client.models._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secret_version._api_v1_secret_approval_requests__id__get_200_response_approval_commits_inner_secretVersion(
                            id = '', 
                            version = 1.337, 
                            secret_key = '', 
                            secret_value = '', 
                            secret_comment = '', ), )
                    ],
        )
        """

    def testApiV1SecretApprovalRequestsIdGet200ResponseApproval(self):
        """Test ApiV1SecretApprovalRequestsIdGet200ResponseApproval"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
