# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_workspace_workspace_id_integrations_get200_response import ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response  # noqa: E501

class TestApiV1WorkspaceWorkspaceIdIntegrationsGet200Response(unittest.TestCase):
    """ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response:
        """Test ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response`
        """
        model = ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response()  # noqa: E501
        if include_optional:
            return ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response(
                integrations = [
                    infisicalapi_client.models._api_v1_workspace__workspace_id__integrations_get_200_response_integrations_inner._api_v1_workspace__workspaceId__integrations_get_200_response_integrations_inner(
                        id = '', 
                        is_active = True, 
                        url = '', 
                        app = '', 
                        app_id = '', 
                        target_environment = '', 
                        target_environment_id = '', 
                        target_service = '', 
                        target_service_id = '', 
                        owner = '', 
                        path = '', 
                        region = '', 
                        scope = '', 
                        integration = '', 
                        metadata = null, 
                        integration_auth_id = '', 
                        env_id = '', 
                        secret_path = '/', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_synced = True, 
                        sync_message = '', 
                        last_sync_job_id = '', 
                        environment = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                            id = '', 
                            name = '', 
                            slug = '', ), )
                    ]
            )
        else:
            return ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response(
                integrations = [
                    infisicalapi_client.models._api_v1_workspace__workspace_id__integrations_get_200_response_integrations_inner._api_v1_workspace__workspaceId__integrations_get_200_response_integrations_inner(
                        id = '', 
                        is_active = True, 
                        url = '', 
                        app = '', 
                        app_id = '', 
                        target_environment = '', 
                        target_environment_id = '', 
                        target_service = '', 
                        target_service_id = '', 
                        owner = '', 
                        path = '', 
                        region = '', 
                        scope = '', 
                        integration = '', 
                        metadata = null, 
                        integration_auth_id = '', 
                        env_id = '', 
                        secret_path = '/', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_synced = True, 
                        sync_message = '', 
                        last_sync_job_id = '', 
                        environment = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                            id = '', 
                            name = '', 
                            slug = '', ), )
                    ],
        )
        """

    def testApiV1WorkspaceWorkspaceIdIntegrationsGet200Response(self):
        """Test ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
