# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from infisicalapi_client.models.api_v1_scim_scim_tokens_get200_response_scim_tokens_inner import ApiV1ScimScimTokensGet200ResponseScimTokensInner

class ApiV1ScimScimTokensGet200Response(BaseModel):
    """
    ApiV1ScimScimTokensGet200Response
    """
    scim_tokens: conlist(ApiV1ScimScimTokensGet200ResponseScimTokensInner) = Field(default=..., alias="scimTokens")
    __properties = ["scimTokens"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1ScimScimTokensGet200Response:
        """Create an instance of ApiV1ScimScimTokensGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in scim_tokens (list)
        _items = []
        if self.scim_tokens:
            for _item in self.scim_tokens:
                if _item:
                    _items.append(_item.to_dict())
            _dict['scimTokens'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1ScimScimTokensGet200Response:
        """Create an instance of ApiV1ScimScimTokensGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1ScimScimTokensGet200Response.parse_obj(obj)

        _obj = ApiV1ScimScimTokensGet200Response.parse_obj({
            "scim_tokens": [ApiV1ScimScimTokensGet200ResponseScimTokensInner.from_dict(_item) for _item in obj.get("scimTokens")] if obj.get("scimTokens") is not None else None
        })
        return _obj


