# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v3_secrets_raw_secret_name_get200_response import ApiV3SecretsRawSecretNameGet200Response  # noqa: E501

class TestApiV3SecretsRawSecretNameGet200Response(unittest.TestCase):
    """ApiV3SecretsRawSecretNameGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV3SecretsRawSecretNameGet200Response:
        """Test ApiV3SecretsRawSecretNameGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV3SecretsRawSecretNameGet200Response`
        """
        model = ApiV3SecretsRawSecretNameGet200Response()  # noqa: E501
        if include_optional:
            return ApiV3SecretsRawSecretNameGet200Response(
                secret = infisicalapi_client.models._api_v3_secrets_raw__secret_name__get_200_response_secret._api_v3_secrets_raw__secretName__get_200_response_secret(
                    id = '', 
                    _id = '', 
                    workspace = '', 
                    environment = '', 
                    version = 1.337, 
                    type = '', 
                    secret_key = '', 
                    secret_value = '', 
                    secret_comment = '', 
                    secret_reminder_note = '', 
                    secret_reminder_repeat_days = 1.337, 
                    skip_multiline_encoding = True, 
                    metadata = null, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    tags = [
                        infisicalapi_client.models._api_v3_secrets_tags__secret_name__post_200_response_secret_tags_inner._api_v3_secrets_tags__secretName__post_200_response_secret_tags_inner(
                            id = '', 
                            slug = '', 
                            color = '', 
                            name = '', )
                        ], )
            )
        else:
            return ApiV3SecretsRawSecretNameGet200Response(
                secret = infisicalapi_client.models._api_v3_secrets_raw__secret_name__get_200_response_secret._api_v3_secrets_raw__secretName__get_200_response_secret(
                    id = '', 
                    _id = '', 
                    workspace = '', 
                    environment = '', 
                    version = 1.337, 
                    type = '', 
                    secret_key = '', 
                    secret_value = '', 
                    secret_comment = '', 
                    secret_reminder_note = '', 
                    secret_reminder_repeat_days = 1.337, 
                    skip_multiline_encoding = True, 
                    metadata = null, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    tags = [
                        infisicalapi_client.models._api_v3_secrets_tags__secret_name__post_200_response_secret_tags_inner._api_v3_secrets_tags__secretName__post_200_response_secret_tags_inner(
                            id = '', 
                            slug = '', 
                            color = '', 
                            name = '', )
                        ], ),
        )
        """

    def testApiV3SecretsRawSecretNameGet200Response(self):
        """Test ApiV3SecretsRawSecretNameGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
