# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_sso_oidc_config_post_request import ApiV1SsoOidcConfigPostRequest  # noqa: E501

class TestApiV1SsoOidcConfigPostRequest(unittest.TestCase):
    """ApiV1SsoOidcConfigPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SsoOidcConfigPostRequest:
        """Test ApiV1SsoOidcConfigPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SsoOidcConfigPostRequest`
        """
        model = ApiV1SsoOidcConfigPostRequest()  # noqa: E501
        if include_optional:
            return ApiV1SsoOidcConfigPostRequest(
                allowed_email_domains = '',
                configuration_type = 'custom',
                issuer = '',
                discovery_url = '',
                authorization_endpoint = '',
                jwks_uri = '',
                token_endpoint = '',
                userinfo_endpoint = '',
                client_id = '',
                client_secret = '',
                is_active = True,
                org_slug = ''
            )
        else:
            return ApiV1SsoOidcConfigPostRequest(
                configuration_type = 'custom',
                client_id = '',
                client_secret = '',
                is_active = True,
                org_slug = '',
        )
        """

    def testApiV1SsoOidcConfigPostRequest(self):
        """Test ApiV1SsoOidcConfigPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
