# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v2_workspace_project_slug_groups_get200_response import ApiV2WorkspaceProjectSlugGroupsGet200Response  # noqa: E501

class TestApiV2WorkspaceProjectSlugGroupsGet200Response(unittest.TestCase):
    """ApiV2WorkspaceProjectSlugGroupsGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV2WorkspaceProjectSlugGroupsGet200Response:
        """Test ApiV2WorkspaceProjectSlugGroupsGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV2WorkspaceProjectSlugGroupsGet200Response`
        """
        model = ApiV2WorkspaceProjectSlugGroupsGet200Response()  # noqa: E501
        if include_optional:
            return ApiV2WorkspaceProjectSlugGroupsGet200Response(
                group_memberships = [
                    infisicalapi_client.models._api_v2_workspace__project_slug__groups_get_200_response_group_memberships_inner._api_v2_workspace__projectSlug__groups_get_200_response_groupMemberships_inner(
                        id = '', 
                        group_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        roles = [
                            infisicalapi_client.models._api_v1_workspace__workspace_id__users_get_200_response_users_inner_roles_inner._api_v1_workspace__workspaceId__users_get_200_response_users_inner_roles_inner(
                                id = '', 
                                role = '', 
                                custom_role_id = '', 
                                custom_role_name = '', 
                                custom_role_slug = '', 
                                is_temporary = True, 
                                temporary_mode = '', 
                                temporary_range = '', 
                                temporary_access_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                temporary_access_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        group = infisicalapi_client.models._api_v2_workspace__project_slug__groups_get_200_response_group_memberships_inner_group._api_v2_workspace__projectSlug__groups_get_200_response_groupMemberships_inner_group(
                            name = '', 
                            id = '', 
                            slug = '', ), )
                    ]
            )
        else:
            return ApiV2WorkspaceProjectSlugGroupsGet200Response(
                group_memberships = [
                    infisicalapi_client.models._api_v2_workspace__project_slug__groups_get_200_response_group_memberships_inner._api_v2_workspace__projectSlug__groups_get_200_response_groupMemberships_inner(
                        id = '', 
                        group_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        roles = [
                            infisicalapi_client.models._api_v1_workspace__workspace_id__users_get_200_response_users_inner_roles_inner._api_v1_workspace__workspaceId__users_get_200_response_users_inner_roles_inner(
                                id = '', 
                                role = '', 
                                custom_role_id = '', 
                                custom_role_name = '', 
                                custom_role_slug = '', 
                                is_temporary = True, 
                                temporary_mode = '', 
                                temporary_range = '', 
                                temporary_access_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                temporary_access_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        group = infisicalapi_client.models._api_v2_workspace__project_slug__groups_get_200_response_group_memberships_inner_group._api_v2_workspace__projectSlug__groups_get_200_response_groupMemberships_inner_group(
                            name = '', 
                            id = '', 
                            slug = '', ), )
                    ],
        )
        """

    def testApiV2WorkspaceProjectSlugGroupsGet200Response(self):
        """Test ApiV2WorkspaceProjectSlugGroupsGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
