# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_external_kms_get200_response_external_kms_list_inner import ApiV1ExternalKmsGet200ResponseExternalKmsListInner  # noqa: E501

class TestApiV1ExternalKmsGet200ResponseExternalKmsListInner(unittest.TestCase):
    """ApiV1ExternalKmsGet200ResponseExternalKmsListInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1ExternalKmsGet200ResponseExternalKmsListInner:
        """Test ApiV1ExternalKmsGet200ResponseExternalKmsListInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1ExternalKmsGet200ResponseExternalKmsListInner`
        """
        model = ApiV1ExternalKmsGet200ResponseExternalKmsListInner()  # noqa: E501
        if include_optional:
            return ApiV1ExternalKmsGet200ResponseExternalKmsListInner(
                id = '',
                description = '',
                is_disabled = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                slug = '',
                external_kms = infisicalapi_client.models._api_v1_external_kms_get_200_response_external_kms_list_inner_external_kms._api_v1_external_kms_get_200_response_externalKmsList_inner_externalKms(
                    provider = '', 
                    status = '', 
                    status_details = '', )
            )
        else:
            return ApiV1ExternalKmsGet200ResponseExternalKmsListInner(
                id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                slug = '',
                external_kms = infisicalapi_client.models._api_v1_external_kms_get_200_response_external_kms_list_inner_external_kms._api_v1_external_kms_get_200_response_externalKmsList_inner_externalKms(
                    provider = '', 
                    status = '', 
                    status_details = '', ),
        )
        """

    def testApiV1ExternalKmsGet200ResponseExternalKmsListInner(self):
        """Test ApiV1ExternalKmsGet200ResponseExternalKmsListInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
