# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v2_service_token_post_request import ApiV2ServiceTokenPostRequest  # noqa: E501

class TestApiV2ServiceTokenPostRequest(unittest.TestCase):
    """ApiV2ServiceTokenPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV2ServiceTokenPostRequest:
        """Test ApiV2ServiceTokenPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV2ServiceTokenPostRequest`
        """
        model = ApiV2ServiceTokenPostRequest()  # noqa: E501
        if include_optional:
            return ApiV2ServiceTokenPostRequest(
                name = '',
                workspace_id = '',
                scopes = [
                    infisicalapi_client.models._api_v2_service_token_post_request_scopes_inner._api_v2_service_token_post_request_scopes_inner(
                        environment = '', 
                        secret_path = '', )
                    ],
                encrypted_key = '',
                iv = '',
                tag = '',
                expires_in = 1.337,
                permissions = [
                    'read'
                    ]
            )
        else:
            return ApiV2ServiceTokenPostRequest(
                name = '',
                workspace_id = '',
                scopes = [
                    infisicalapi_client.models._api_v2_service_token_post_request_scopes_inner._api_v2_service_token_post_request_scopes_inner(
                        environment = '', 
                        secret_path = '', )
                    ],
                encrypted_key = '',
                iv = '',
                tag = '',
                expires_in = 1.337,
                permissions = [
                    'read'
                    ],
        )
        """

    def testApiV2ServiceTokenPostRequest(self):
        """Test ApiV2ServiceTokenPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
