# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_auth_universal_auth_identities_identity_id_client_secrets_client_secret_id_get200_response import ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response  # noqa: E501

class TestApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response(unittest.TestCase):
    """ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response:
        """Test ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response`
        """
        model = ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response()  # noqa: E501
        if include_optional:
            return ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response(
                client_secret_data = infisicalapi_client.models._api_v1_auth_universal_auth_identities__identity_id__client_secrets_get_200_response_client_secret_data_inner._api_v1_auth_universal_auth_identities__identityId__client_secrets_get_200_response_clientSecretData_inner(
                    id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    client_secret_prefix = '', 
                    client_secret_num_uses = 1.337, 
                    client_secret_num_uses_limit = 1.337, 
                    client_secret_ttl = 1.337, 
                    identity_uaid = '', 
                    is_client_secret_revoked = True, )
            )
        else:
            return ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response(
                client_secret_data = infisicalapi_client.models._api_v1_auth_universal_auth_identities__identity_id__client_secrets_get_200_response_client_secret_data_inner._api_v1_auth_universal_auth_identities__identityId__client_secrets_get_200_response_clientSecretData_inner(
                    id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    client_secret_prefix = '', 
                    client_secret_num_uses = 1.337, 
                    client_secret_num_uses_limit = 1.337, 
                    client_secret_ttl = 1.337, 
                    identity_uaid = '', 
                    is_client_secret_revoked = True, ),
        )
        """

    def testApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response(self):
        """Test ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
