# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response_secret_snapshot_secret_versions_inner import ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner  # noqa: E501

class TestApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner(unittest.TestCase):
    """ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner:
        """Test ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner`
        """
        model = ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner()  # noqa: E501
        if include_optional:
            return ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner(
                id = '',
                version = 1.337,
                secret_key = '',
                secret_value = '',
                secret_comment = '',
                secret_reminder_note = '',
                secret_reminder_repeat_days = 1.337,
                skip_multiline_encoding = True,
                metadata = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                secret_id = '',
                tags = [
                    infisicalapi_client.models._api_v1_secret_snapshot__secret_snapshot_id__get_200_response_secret_snapshot_secret_versions_inner_tags_inner._api_v1_secret_snapshot__secretSnapshotId__get_200_response_secretSnapshot_secretVersions_inner_tags_inner(
                        id = '', 
                        slug = '', 
                        color = '', )
                    ]
            )
        else:
            return ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner(
                id = '',
                version = 1.337,
                secret_key = '',
                secret_value = '',
                secret_comment = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                secret_id = '',
                tags = [
                    infisicalapi_client.models._api_v1_secret_snapshot__secret_snapshot_id__get_200_response_secret_snapshot_secret_versions_inner_tags_inner._api_v1_secret_snapshot__secretSnapshotId__get_200_response_secretSnapshot_secretVersions_inner_tags_inner(
                        id = '', 
                        slug = '', 
                        color = '', )
                    ],
        )
        """

    def testApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner(self):
        """Test ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
