# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime

from pydantic import BaseModel, Field, StrictBool, StrictStr, validator

class ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1(BaseModel):
    """
    ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1
    """
    role: StrictStr = Field(default=..., description="The role slug to assign to the newly created identity project membership.")
    is_temporary: StrictBool = Field(default=..., alias="isTemporary", description="Whether the assigned role is temporary. If isTemporary is set true, must provide temporaryMode, temporaryRange and temporaryAccessStartTime.")
    temporary_mode: StrictStr = Field(default=..., alias="temporaryMode", description="Type of temporary expiry.")
    temporary_range: StrictStr = Field(default=..., alias="temporaryRange", description="Expiry time for temporary access. In relative mode it could be 1s,2m,3h")
    temporary_access_start_time: datetime = Field(default=..., alias="temporaryAccessStartTime", description="Time to which the temporary access starts")
    __properties = ["role", "isTemporary", "temporaryMode", "temporaryRange", "temporaryAccessStartTime"]

    @validator('temporary_mode')
    def temporary_mode_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('relative'):
            raise ValueError("must be one of enum values ('relative')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1:
        """Create an instance of ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1:
        """Create an instance of ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1.parse_obj(obj)

        _obj = ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1.parse_obj({
            "role": obj.get("role"),
            "is_temporary": obj.get("isTemporary"),
            "temporary_mode": obj.get("temporaryMode"),
            "temporary_range": obj.get("temporaryRange"),
            "temporary_access_start_time": obj.get("temporaryAccessStartTime")
        })
        return _obj


