# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_rotation_providers_workspace_id_get200_response import ApiV1SecretRotationProvidersWorkspaceIdGet200Response  # noqa: E501

class TestApiV1SecretRotationProvidersWorkspaceIdGet200Response(unittest.TestCase):
    """ApiV1SecretRotationProvidersWorkspaceIdGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretRotationProvidersWorkspaceIdGet200Response:
        """Test ApiV1SecretRotationProvidersWorkspaceIdGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretRotationProvidersWorkspaceIdGet200Response`
        """
        model = ApiV1SecretRotationProvidersWorkspaceIdGet200Response()  # noqa: E501
        if include_optional:
            return ApiV1SecretRotationProvidersWorkspaceIdGet200Response(
                providers = [
                    infisicalapi_client.models._api_v1_secret_rotation_providers__workspace_id__get_200_response_providers_inner._api_v1_secret_rotation_providers__workspaceId__get_200_response_providers_inner(
                        name = '', 
                        title = '', 
                        image = '', 
                        description = '', 
                        template = null, )
                    ]
            )
        else:
            return ApiV1SecretRotationProvidersWorkspaceIdGet200Response(
                providers = [
                    infisicalapi_client.models._api_v1_secret_rotation_providers__workspace_id__get_200_response_providers_inner._api_v1_secret_rotation_providers__workspaceId__get_200_response_providers_inner(
                        name = '', 
                        title = '', 
                        image = '', 
                        description = '', 
                        template = null, )
                    ],
        )
        """

    def testApiV1SecretRotationProvidersWorkspaceIdGet200Response(self):
        """Test ApiV1SecretRotationProvidersWorkspaceIdGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
