# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictBool, StrictStr

class ApiV1LdapConfigGet200Response(BaseModel):
    """
    ApiV1LdapConfigGet200Response
    """
    id: StrictStr = Field(...)
    organization: StrictStr = Field(...)
    is_active: StrictBool = Field(default=..., alias="isActive")
    url: StrictStr = Field(...)
    bind_dn: StrictStr = Field(default=..., alias="bindDN")
    bind_pass: StrictStr = Field(default=..., alias="bindPass")
    unique_user_attribute: StrictStr = Field(default=..., alias="uniqueUserAttribute")
    search_base: StrictStr = Field(default=..., alias="searchBase")
    search_filter: StrictStr = Field(default=..., alias="searchFilter")
    group_search_base: StrictStr = Field(default=..., alias="groupSearchBase")
    group_search_filter: StrictStr = Field(default=..., alias="groupSearchFilter")
    ca_cert: StrictStr = Field(default=..., alias="caCert")
    __properties = ["id", "organization", "isActive", "url", "bindDN", "bindPass", "uniqueUserAttribute", "searchBase", "searchFilter", "groupSearchBase", "groupSearchFilter", "caCert"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1LdapConfigGet200Response:
        """Create an instance of ApiV1LdapConfigGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1LdapConfigGet200Response:
        """Create an instance of ApiV1LdapConfigGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1LdapConfigGet200Response.parse_obj(obj)

        _obj = ApiV1LdapConfigGet200Response.parse_obj({
            "id": obj.get("id"),
            "organization": obj.get("organization"),
            "is_active": obj.get("isActive"),
            "url": obj.get("url"),
            "bind_dn": obj.get("bindDN"),
            "bind_pass": obj.get("bindPass"),
            "unique_user_attribute": obj.get("uniqueUserAttribute"),
            "search_base": obj.get("searchBase"),
            "search_filter": obj.get("searchFilter"),
            "group_search_base": obj.get("groupSearchBase"),
            "group_search_filter": obj.get("groupSearchFilter"),
            "ca_cert": obj.get("caCert")
        })
        return _obj


