# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_scim_groups_group_id_patch_request_operations_inner_any_of import ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf  # noqa: E501

class TestApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf(unittest.TestCase):
    """ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf:
        """Test ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf`
        """
        model = ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf()  # noqa: E501
        if include_optional:
            return ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf(
                op = 'replace',
                value = infisicalapi_client.models._api_v1_scim_groups__group_id__patch_request_operations_inner_any_of_value._api_v1_scim_Groups__groupId__patch_request_Operations_inner_anyOf_value(
                    id = '', 
                    display_name = '', )
            )
        else:
            return ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf(
                op = 'replace',
                value = infisicalapi_client.models._api_v1_scim_groups__group_id__patch_request_operations_inner_any_of_value._api_v1_scim_Groups__groupId__patch_request_Operations_inner_anyOf_value(
                    id = '', 
                    display_name = '', ),
        )
        """

    def testApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf(self):
        """Test ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
