# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_scim_groups_post200_response import ApiV1ScimGroupsPost200Response  # noqa: E501

class TestApiV1ScimGroupsPost200Response(unittest.TestCase):
    """ApiV1ScimGroupsPost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1ScimGroupsPost200Response:
        """Test ApiV1ScimGroupsPost200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1ScimGroupsPost200Response`
        """
        model = ApiV1ScimGroupsPost200Response()  # noqa: E501
        if include_optional:
            return ApiV1ScimGroupsPost200Response(
                schemas = [
                    ''
                    ],
                id = '',
                display_name = '',
                members = [
                    infisicalapi_client.models._api_v1_scim_users__org_membership_id__get_201_response_groups_inner._api_v1_scim_Users__orgMembershipId__get_201_response_groups_inner(
                        value = '', 
                        display = '', )
                    ],
                meta = infisicalapi_client.models._api_v1_scim_groups_get_200_response_resources_inner_meta._api_v1_scim_Groups_get_200_response_Resources_inner_meta(
                    resource_type = '', )
            )
        else:
            return ApiV1ScimGroupsPost200Response(
                schemas = [
                    ''
                    ],
                id = '',
                display_name = '',
                meta = infisicalapi_client.models._api_v1_scim_groups_get_200_response_resources_inner_meta._api_v1_scim_Groups_get_200_response_Resources_inner_meta(
                    resource_type = '', ),
        )
        """

    def testApiV1ScimGroupsPost200Response(self):
        """Test ApiV1ScimGroupsPost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
