# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_imports_secret_import_id_patch_request import ApiV1SecretImportsSecretImportIdPatchRequest  # noqa: E501

class TestApiV1SecretImportsSecretImportIdPatchRequest(unittest.TestCase):
    """ApiV1SecretImportsSecretImportIdPatchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretImportsSecretImportIdPatchRequest:
        """Test ApiV1SecretImportsSecretImportIdPatchRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretImportsSecretImportIdPatchRequest`
        """
        model = ApiV1SecretImportsSecretImportIdPatchRequest()  # noqa: E501
        if include_optional:
            return ApiV1SecretImportsSecretImportIdPatchRequest(
                workspace_id = '',
                environment = '',
                path = '/',
                var_import = infisicalapi_client.models._api_v1_secret_imports__secret_import_id__patch_request_import._api_v1_secret_imports__secretImportId__patch_request_import(
                    environment = '', 
                    path = '', 
                    position = 1.337, )
            )
        else:
            return ApiV1SecretImportsSecretImportIdPatchRequest(
                workspace_id = '',
                environment = '',
                var_import = infisicalapi_client.models._api_v1_secret_imports__secret_import_id__patch_request_import._api_v1_secret_imports__secretImportId__patch_request_import(
                    environment = '', 
                    path = '', 
                    position = 1.337, ),
        )
        """

    def testApiV1SecretImportsSecretImportIdPatchRequest(self):
        """Test ApiV1SecretImportsSecretImportIdPatchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
