# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_additional_privilege_identity_permanent_post_request_privilege_permission import ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission  # noqa: E501

class TestApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission(unittest.TestCase):
    """ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission:
        """Test ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission`
        """
        model = ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission()  # noqa: E501
        if include_optional:
            return ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission(
                actions = [
                    'read'
                    ],
                subject = 'secrets',
                conditions = infisicalapi_client.models._api_v1_additional_privilege_identity_permanent_post_request_privilege_permission_conditions._api_v1_additional_privilege_identity_permanent_post_request_privilegePermission_conditions(
                    environment = '', 
                    secret_path = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_request_permissions_inner_conditions_secret_path._api_v1_workspace__projectSlug__roles_post_request_permissions_inner_conditions_secretPath(
                        __glob = '0', ), )
            )
        else:
            return ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission(
                actions = [
                    'read'
                    ],
                subject = 'secrets',
                conditions = infisicalapi_client.models._api_v1_additional_privilege_identity_permanent_post_request_privilege_permission_conditions._api_v1_additional_privilege_identity_permanent_post_request_privilegePermission_conditions(
                    environment = '', 
                    secret_path = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_request_permissions_inner_conditions_secret_path._api_v1_workspace__projectSlug__roles_post_request_permissions_inner_conditions_secretPath(
                        __glob = '0', ), ),
        )
        """

    def testApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission(self):
        """Test ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
