# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_admin_signup_post_request import ApiV1AdminSignupPostRequest  # noqa: E501

class TestApiV1AdminSignupPostRequest(unittest.TestCase):
    """ApiV1AdminSignupPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AdminSignupPostRequest:
        """Test ApiV1AdminSignupPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AdminSignupPostRequest`
        """
        model = ApiV1AdminSignupPostRequest()  # noqa: E501
        if include_optional:
            return ApiV1AdminSignupPostRequest(
                email = '',
                password = '',
                first_name = '',
                last_name = '',
                protected_key = '',
                protected_key_iv = '',
                protected_key_tag = '',
                public_key = '',
                encrypted_private_key = '',
                encrypted_private_key_iv = '',
                encrypted_private_key_tag = '',
                salt = '',
                verifier = ''
            )
        else:
            return ApiV1AdminSignupPostRequest(
                email = '',
                password = '',
                first_name = '',
                protected_key = '',
                protected_key_iv = '',
                protected_key_tag = '',
                public_key = '',
                encrypted_private_key = '',
                encrypted_private_key_iv = '',
                encrypted_private_key_tag = '',
                salt = '',
                verifier = '',
        )
        """

    def testApiV1AdminSignupPostRequest(self):
        """Test ApiV1AdminSignupPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
